@@ -19,13 +19,13 @@ class Build:
         Name for the dataset
     """
 
-    def __init__(self, name=None, subtitle=None, default_dataset=None, table_of_contents=False):
+    def __init__(self, name=None, subtitle=None, default_dataset=None, table_of_contents=False, logo=None):
         self.name = name
         self.subtitle = subtitle
         self.default_dataset = default_dataset
         self.table_of_contents = table_of_contents
         self.sheets = []
-        self.logo_path = None
+        self.logo = logo
         self.font_name = None
         self.font_size = None
         self.index_options = {
@@ -34,30 +34,24 @@ class Build:
             'link_color': '2A64C5'
         }
         self.options = Options(
-            table_options= {
-                "format":{
-                    "base":{},
-                    "percentage":{},
-                    "counts":{}
-                },
-                "stub": {"ci":["c%"]},
-                "banner_border": True
-            },
-            formats=copy.deepcopy(build_default_formats)
+            formats=copy.deepcopy(build_default_formats),
+            parent=self
         )
 
     def add_sheet(self, name=None, banner='@'):
+        if name is None:
+            name = "Table {}".format(str(len(self.sheets)+1))
         sheet = Sheet(
             banner=banner, 
             default_dataset=self.default_dataset, 
-            table_options=self.options.table_options, 
-            formats=self.options.formats
+            name=name,
+            parent=self
             )
         self.sheets.append(sheet)
         return sheet
 
     def add_logo(self, path):
-        self.logo_path = path
+        self.logo = path
 
     def set_index_option(self, name, option):
         self.index_options[name] = option
@@ -66,7 +60,7 @@ class Build:
         dataframes_payload = []
         formats = []
         for sheet in self.sheets:
-            df = sheet.combine_dataframes()
+            df = sheet.build_dataframes(self.options)
             df = df.replace({'null':0})
             payload = json.loads(df.to_json(orient='split'))
             payload['index_names'] = df.index.names.copy()
@@ -105,8 +99,8 @@ class Build:
                     cell = wb_sheet.cell(row=index+1+offset_y, column=2, value=link_value)
                     cell.font = Font(color="2A64C5", underline="single")
 
-                if self.logo_path is not None:
-                    img = Image(self.logo_path)
+                if self.logo is not None:
+                    img = Image(self.logo)
                     wb_sheet.add_image(img, 'B2')
 
                 for row_range in range(1, 10):
@@ -139,8 +133,8 @@ class Build:
 
             else:
                 wb_sheet = wb.worksheets[0]
-                if self.logo_path is not None:                
-                    img = Image(self.logo_path)
+                if self.logo is not None:                
+                    img = Image(self.logo)
                     wb_sheet.add_image(img, 'B2')
 
                 for row_range in range(1, self.sheets[0].options.formats['offsets']['top']+1):
@@ -162,3 +156,7 @@ class Build:
             print('Warning: Something went wrong in prettifying the Excel. Make sure all colors are defined as ffffff rather than #ffffff.')
             print(e)
             pass
+
+    def table_count(self):
+        table_counts = [i.table_count() for i in self.sheets]
+        return sum(table_counts)
