@@ -4,18 +4,13 @@ import pandas as pd
 import copy
 
 class Sheet:
-    def __init__(self, banner='@', default_dataset=None, name=None, table_options=None, formats=None):
+    def __init__(self, banner='@', default_dataset=None, name=None, parent=None):
         self.banner = banner
-        self.dataframes = []
+        self.tables = []
         self.default_dataset = default_dataset
         self.name = name
-        self.options = Options(
-            table_options = copy.deepcopy(table_options),
-            formats = copy.deepcopy(formats)
-        )
-
-        self.options.set_question_format('percentage', {'text_wrap':True})
-        self.options.set_question_format('counts', {'text_wrap':True})
+        self.options = Options(parent=self)
+        self.parent = parent
 
     def get_name(self):
         if self.name is not None:
@@ -24,7 +19,8 @@ class Sheet:
             if len(self.dataframes)>0:
                 name = self.dataframes[0].index.get_level_values(0)[0]
                 if name == 'Base' or name == 'Unweighted base':
-                    return self.dataframes[0][~self.dataframes[0]['FORMAT'].str.contains('base')].index[0][0]                       
+                    #check the format column if this is either a base or space row
+                    return self.dataframes[0][~self.dataframes[0]['FORMAT'].str.contains('base|spacer', regex=True, case=False)].index[0][0]                       
                 else:
                     return name
             else:
@@ -33,16 +29,23 @@ class Sheet:
     def add_table(self, stub, options={}, dataset=None):
         if self.default_dataset and dataset is None:
             dataset = self.default_dataset
-        crosstab = {**{**self.options.table_options['stub'], **stub}, **{'y':self.banner, 'add_format_column':True}}
+        merged_table_options = self.options.merge_dict(self.options.table_options, self.parent.options.table_options)
+        crosstab = {**{**merged_table_options['stub'], **stub}, **{'y':self.banner, 'add_format_column':True}}
         df = dataset.crosstab(
             crosstabs=[crosstab]
         )
-        options = {**self.options.table_options, **options}
-        # the format column should always have a cell_options key
-        df['FORMAT'] = df['FORMAT'].apply(lambda x: json.dumps({**json.loads(x), **{'cell_format':{}}}))
-        df = self.apply_table_options(df, options)
-        df = self._append_row_to_dataframe(df)
-        self.dataframes.append(df)
+        self.tables.append({"dataframe":df, "options":options})
+
+    def paint_dataframes(self):
+        for table in self.tables:
+            options = {**self.options.table_options, **table['options']}
+            df = table['dataframe']
+            # the format column should always have a cell_options key
+            df['FORMAT'] = df['FORMAT'].apply(lambda x: json.dumps({**json.loads(x), **{'cell_format':{}}}))
+            df = self.apply_table_options(df, options)
+            df = self._append_row_to_dataframe(df)
+            table['dataframe'] = df
+
 
     def apply_table_options(self, df, options):
         if 'base' in options:
@@ -126,7 +129,14 @@ class Sheet:
         return df
 
     def add_banner_border(self, df):
-        all_questions = df.columns.to_frame().index.to_series().reset_index()['Question']
+        # when we decide where to put the vertical border, we drop all the levels we won't use for the border
+        # if we have nested banners
+        df_for_index_calculation = df.copy()
+        nested_depth = len([i for i in df.columns.droplevel(0).names if i =='Values'])
+        if nested_depth > 1:
+            drop_how_many = (nested_depth - 1)*2
+            df_for_index_calculation.columns = df.columns.droplevel(level=list(range(drop_how_many)))
+        all_questions = df_for_index_calculation.columns.to_frame().index.to_series().reset_index()['Question']
         # find location of first unique question (this is the far left column in each subframe)
         all_questions = list(all_questions.drop_duplicates().iloc[:-1].index)
         # the question column is col 0 and we don't count that
@@ -168,5 +178,16 @@ class Sheet:
         df = pd.concat([df, empty_row_df])
         return df
 
-    def combine_dataframes(self):
-        return pd.concat(self.dataframes)
+    def build_dataframes(self, build_options=None):
+        if len(self.tables) == 0:
+            raise Exception("Sheet {} has no tables".format(self.name))
+        self.options.merge(build_options)
+        self.options.set_question_format('percentage', {'text_wrap':True})
+        self.options.set_question_format('counts', {'text_wrap':True})
+
+        self.paint_dataframes()
+        dataframes = [i['dataframe'] for i in self.tables]
+        return pd.concat(dataframes)
+
+    def table_count(self):
+        return len(self.tables)
\ No newline at end of file
